# sandlerprops

> A Python interface to the pure-component properties database that originally accompanied the textbook _Chemical, Biochemical, and Engineering Thermodynamics_ (4th edition) by Stan Sandler (Wiley, USA).

Full documentation is available at [https://sandlerprops.readthedocs.io/en/stable/index.html](https://sandlerprops.readthedocs.io/en/stable/index.html).
